@@ -14,8 +14,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains the Apache Livy hook."""
-
 from __future__ import annotations
 
 import asyncio
@@ -530,7 +528,7 @@ class LivyAsyncHook(HttpAsyncHook):
         if self.http_conn_id:
             conn = await sync_to_async(self.get_connection)(self.http_conn_id)
 
-            self.base_url = self._generate_base_url(conn)
+            self.base_url = self._generate_base_url(conn)  # type: ignore[arg-type]
             if conn.login:
                 auth = self.auth_type(conn.login, conn.password)
             if conn.extra:
@@ -695,9 +693,8 @@ class LivyAsyncHook(HttpAsyncHook):
                 for log_line in log_lines:
                     self.log.info(log_line)
                 return log_lines
-            else:
-                self.log.info(result["response"])
-                return result["response"]
+            self.log.info(result["response"])
+            return result["response"]
 
     @staticmethod
     def _validate_session_id(session_id: int | str) -> None:
